@@ -27,24 +27,22 @@ import (
 )
 
 var (
-	defaultCheServerImage                       string
-	defaultCheVersion                           string
-	defaultDashboardImage                       string
-	defaultDevworkspaceCheOperatorImage         string
-	defaultDevworkspaceControllerImage          string
-	defaultPluginRegistryImage                  string
-	defaultDevfileRegistryImage                 string
-	defaultCheTLSSecretsCreationJobImage        string
-	defaultPvcJobsImage                         string
-	defaultPostgresImage                        string
-	defaultKeycloakImage                        string
-	defaultSingleHostGatewayImage               string
-	defaultSingleHostGatewayImageNativeUserMode string
-	defaultSingleHostGatewayConfigSidecarImage  string
-	defaultInternalRestBackupServerImage        string
-	defaultGatewayAuthenticationSidecarImage    string
-	defaultGatewayAuthorizationSidecarImage     string
-	defaultGatewayHeaderProxySidecarImage       string
+	defaultCheServerImage                      string
+	defaultCheVersion                          string
+	defaultDashboardImage                      string
+	defaultDevworkspaceControllerImage         string
+	defaultPluginRegistryImage                 string
+	defaultDevfileRegistryImage                string
+	defaultCheTLSSecretsCreationJobImage       string
+	defaultPvcJobsImage                        string
+	defaultPostgresImage                       string
+	defaultKeycloakImage                       string
+	defaultSingleHostGatewayImage              string
+	defaultSingleHostGatewayConfigSidecarImage string
+	defaultInternalRestBackupServerImage       string
+	defaultGatewayAuthenticationSidecarImage   string
+	defaultGatewayAuthorizationSidecarImage    string
+	defaultGatewayHeaderProxySidecarImage      string
 
 	defaultCheWorkspacePluginBrokerMetadataImage  string
 	defaultCheWorkspacePluginBrokerArtifactsImage string
@@ -176,7 +174,6 @@ func InitDefaultsFromFile(defaultsPath string) {
 	defaultCheVersion = util.GetDeploymentEnv(operatorDeployment, "CHE_VERSION")
 	defaultCheServerImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_che_server"))
 	defaultDashboardImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_dashboard"))
-	defaultDevworkspaceCheOperatorImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_che_operator"))
 	defaultDevworkspaceControllerImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_controller"))
 	defaultPluginRegistryImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_plugin_registry"))
 	defaultDevfileRegistryImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_devfile_registry"))
@@ -184,14 +181,13 @@ func InitDefaultsFromFile(defaultsPath string) {
 	defaultPostgresImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_postgres"))
 	defaultKeycloakImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_keycloak"))
 	defaultSingleHostGatewayImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_single_host_gateway"))
-	defaultSingleHostGatewayImageNativeUserMode = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_single_host_gateway_native_user_mode"))
 	defaultSingleHostGatewayConfigSidecarImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_single_host_gateway_config_sidecar"))
-	// defaultGatewayAuthenticationSidecarImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authentication_sidecar"))
-	// defaultGatewayAuthorizationSidecarImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authorization_sidecar"))
+	defaultGatewayAuthenticationSidecarImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authentication_sidecar"))
+	defaultGatewayAuthorizationSidecarImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authorization_sidecar"))
 	defaultCheWorkspacePluginBrokerMetadataImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_che_workspace_plugin_broker_metadata"))
 	defaultCheWorkspacePluginBrokerArtifactsImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_che_workspace_plugin_broker_artifacts"))
 	defaultCheServerSecureExposerJwtProxyImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_che_server_secure_exposer_jwt_proxy_image"))
-	// defaultInternalRestBackupServerImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_internal_rest_backup_server"))
+	defaultInternalRestBackupServerImage = util.GetDeploymentEnv(operatorDeployment, util.GetArchitectureDependentEnv("RELATED_IMAGE_internal_rest_backup_server"))
 
 	// Don't get some k8s specific env
 	if !util.IsOpenShift {
@@ -250,6 +246,10 @@ func DefaultConsoleLinkName() string {
 	return getDefaultFromEnv("CONSOLE_LINK_NAME")
 }
 
+func IsDevWorkspaceEngineAllowed() bool {
+	return getDefaultFromEnv("ALLOW_DEVWORKSPACE_ENGINE") == "true"
+}
+
 func DefaultConsoleLinkDisplayName() string {
 	return getDefaultFromEnv("CONSOLE_LINK_DISPLAY_NAME")
 }
@@ -302,10 +302,6 @@ func DefaultDevworkspaceControllerImage(cr *orgv1.CheCluster) string {
 	return patchDefaultImageName(cr, defaultDevworkspaceControllerImage)
 }
 
-func DefaultDevworkspaceCheOperatorImage(cr *orgv1.CheCluster) string {
-	return patchDefaultImageName(cr, defaultDevworkspaceCheOperatorImage)
-}
-
 func DefaultKeycloakImage(cr *orgv1.CheCluster) string {
 	return patchDefaultImageName(cr, defaultKeycloakImage)
 }
@@ -331,15 +327,7 @@ func DefaultCheServerSecureExposerJwtProxyImage(cr *orgv1.CheCluster) string {
 }
 
 func DefaultSingleHostGatewayImage(cr *orgv1.CheCluster) string {
-	// `nativeUserMode` uses Traefik local plugins, which is supported from version 2.5 that is
-	// currently in Release Candidate. As we don't want to use RC version in our stable release,
-	// we're using 2 images now. As soon as Traefik 2.5 stable will be releases, we will remove
-	// `defaultSingleHostGatewayImageNativeUserMode` and use single image again.
-	if util.IsNativeUserModeEnabled(cr) {
-		return patchDefaultImageName(cr, defaultSingleHostGatewayImageNativeUserMode)
-	} else {
-		return patchDefaultImageName(cr, defaultSingleHostGatewayImage)
-	}
+	return patchDefaultImageName(cr, defaultSingleHostGatewayImage)
 }
 
 func DefaultSingleHostGatewayConfigSidecarImage(cr *orgv1.CheCluster) string {
@@ -372,7 +360,7 @@ func DefaultPullPolicyFromDockerImage(dockerImage string) string {
 	if len(parts) > 1 {
 		tag = parts[1]
 	}
-	if tag == "latest" || tag == "nightly" {
+	if tag == "latest" || tag == "nightly" || tag == "next" {
 		return "Always"
 	}
 	return "IfNotPresent"
@@ -457,7 +445,6 @@ func InitDefaultsFromEnv() {
 	defaultCheVersion = getDefaultFromEnv("CHE_VERSION")
 	defaultCheServerImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_che_server"))
 	defaultDashboardImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_dashboard"))
-	defaultDevworkspaceCheOperatorImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_che_operator"))
 	defaultDevworkspaceControllerImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devworkspace_controller"))
 	defaultPluginRegistryImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_plugin_registry"))
 	defaultDevfileRegistryImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_devfile_registry"))
@@ -465,11 +452,10 @@ func InitDefaultsFromEnv() {
 	defaultPostgresImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_postgres"))
 	defaultKeycloakImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_keycloak"))
 	defaultSingleHostGatewayImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_single_host_gateway"))
-	defaultSingleHostGatewayImageNativeUserMode = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_single_host_gateway_native_user_mode"))
 	defaultSingleHostGatewayConfigSidecarImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_single_host_gateway_config_sidecar"))
-	// defaultInternalRestBackupServerImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_internal_rest_backup_server"))
-	// defaultGatewayAuthenticationSidecarImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authentication_sidecar"))
-	// defaultGatewayAuthorizationSidecarImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authorization_sidecar"))
+	defaultInternalRestBackupServerImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_internal_rest_backup_server"))
+	defaultGatewayAuthenticationSidecarImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authentication_sidecar"))
+	defaultGatewayAuthorizationSidecarImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_authorization_sidecar"))
 	// defaultGatewayHeaderProxySidecarImage = getDefaultFromEnv(util.GetArchitectureDependentEnv("RELATED_IMAGE_gateway_header_sidecar"))
 
 	// CRW images for that are mentioned in the Che server che.properties
