@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2020-2020 Red Hat, Inc.
+// Copyright (c) 2020-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -14,7 +14,7 @@ package server
 import "github.com/eclipse-che/che-operator/pkg/deploy"
 
 func init() {
-	err := deploy.InitTestDefaultsFromDeployment("../../../deploy/operator.yaml")
+	err := deploy.InitTestDefaultsFromDeployment("../../../config/manager/manager.yaml")
 	if err != nil {
 		panic(err)
 	}
